/*******************************************************************************
* File Name: CLK50.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CLK50_H)
#define CY_CLOCK_CLK50_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void CLK50_Start(void) ;
void CLK50_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CLK50_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void CLK50_StandbyPower(uint8 state) ;
void CLK50_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 CLK50_GetDividerRegister(void) ;
void CLK50_SetModeRegister(uint8 modeBitMask) ;
void CLK50_ClearModeRegister(uint8 modeBitMask) ;
uint8 CLK50_GetModeRegister(void) ;
void CLK50_SetSourceRegister(uint8 clkSource) ;
uint8 CLK50_GetSourceRegister(void) ;
#if defined(CLK50__CFG3)
void CLK50_SetPhaseRegister(uint8 clkPhase) ;
uint8 CLK50_GetPhaseRegister(void) ;
#endif /* defined(CLK50__CFG3) */

#define CLK50_Enable()                       CLK50_Start()
#define CLK50_Disable()                      CLK50_Stop()
#define CLK50_SetDivider(clkDivider)         CLK50_SetDividerRegister(clkDivider, 1)
#define CLK50_SetDividerValue(clkDivider)    CLK50_SetDividerRegister((clkDivider) - 1, 1)
#define CLK50_SetMode(clkMode)               CLK50_SetModeRegister(clkMode)
#define CLK50_SetSource(clkSource)           CLK50_SetSourceRegister(clkSource)
#if defined(CLK50__CFG3)
#define CLK50_SetPhase(clkPhase)             CLK50_SetPhaseRegister(clkPhase)
#define CLK50_SetPhaseValue(clkPhase)        CLK50_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(CLK50__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CLK50_CLKEN              (* (reg8 *) CLK50__PM_ACT_CFG)
#define CLK50_CLKEN_PTR          ((reg8 *) CLK50__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CLK50_CLKSTBY            (* (reg8 *) CLK50__PM_STBY_CFG)
#define CLK50_CLKSTBY_PTR        ((reg8 *) CLK50__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CLK50_DIV_LSB            (* (reg8 *) CLK50__CFG0)
#define CLK50_DIV_LSB_PTR        ((reg8 *) CLK50__CFG0)
#define CLK50_DIV_PTR            ((reg16 *) CLK50__CFG0)

/* Clock MSB divider configuration register. */
#define CLK50_DIV_MSB            (* (reg8 *) CLK50__CFG1)
#define CLK50_DIV_MSB_PTR        ((reg8 *) CLK50__CFG1)

/* Mode and source configuration register */
#define CLK50_MOD_SRC            (* (reg8 *) CLK50__CFG2)
#define CLK50_MOD_SRC_PTR        ((reg8 *) CLK50__CFG2)

#if defined(CLK50__CFG3)
/* Analog clock phase configuration register */
#define CLK50_PHASE              (* (reg8 *) CLK50__CFG3)
#define CLK50_PHASE_PTR          ((reg8 *) CLK50__CFG3)
#endif /* defined(CLK50__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CLK50_CLKEN_MASK         CLK50__PM_ACT_MSK
#define CLK50_CLKSTBY_MASK       CLK50__PM_STBY_MSK

/* CFG2 field masks */
#define CLK50_SRC_SEL_MSK        CLK50__CFG2_SRC_SEL_MASK
#define CLK50_MODE_MASK          (~(CLK50_SRC_SEL_MSK))

#if defined(CLK50__CFG3)
/* CFG3 phase mask */
#define CLK50_PHASE_MASK         CLK50__CFG3_PHASE_DLY_MASK
#endif /* defined(CLK50__CFG3) */

#endif /* CY_CLOCK_CLK50_H */


/* [] END OF FILE */
