/*******************************************************************************
* File Name: DRAW.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "DRAW.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 DRAW__PORT == 15 && ((DRAW__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: DRAW_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void DRAW_Write(uint8 value) 
{
    uint8 staticBits = (DRAW_DR & (uint8)(~DRAW_MASK));
    DRAW_DR = staticBits | ((uint8)(value << DRAW_SHIFT) & DRAW_MASK);
}


/*******************************************************************************
* Function Name: DRAW_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void DRAW_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DRAW_0, mode);
}


/*******************************************************************************
* Function Name: DRAW_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DRAW_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DRAW_Read(void) 
{
    return (DRAW_PS & DRAW_MASK) >> DRAW_SHIFT;
}


/*******************************************************************************
* Function Name: DRAW_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DRAW_ReadDataReg(void) 
{
    return (DRAW_DR & DRAW_MASK) >> DRAW_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DRAW_INTSTAT) 

    /*******************************************************************************
    * Function Name: DRAW_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DRAW_ClearInterrupt(void) 
    {
        return (DRAW_INTSTAT & DRAW_MASK) >> DRAW_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
