/*******************************************************************************
* File Name: GraphicLCDCtrl_1.h
* Version 1.70
*
* Description:
*  This file provides constants and parameter values and API definition for the 
*  GraphicLCDCtrl Component
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_GraphicLCDCtrl_GraphicLCDCtrl_1_H)
#define CY_GraphicLCDCtrl_GraphicLCDCtrl_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#ifndef CY_PSOC5A
    #error Component GraphicLCDCtrl_v1_70 requires cy_boot v3.0 or later
#endif /* CY_PSOC5A */


/*************************************** 
*   Conditional Compilation Parameters
***************************************/


/***************************************
*        Structure Definitions
***************************************/

/* Sleep Mode API Support */
typedef struct _GraphicLCDCtrl_1_backupStruct
{   
    uint8   enableState;
    
    /* Horizontal timing configuration */
    uint8   horizBp;        /* Back Porch    (F0) */
    uint8   horizAct;       /* Active Region (F1) */
    #if (CY_UDB_V0)
        uint8   horizFp;    /* Front Porch (D0) */
        uint8   horizSync;  /* Sync Widht  (D1) */
    #endif /* (CY_UDB_V0) */
    
    /* Vertical timing configuration */
    uint8   vertBp;         /* Back Porch    (F0) */    
    uint8   vertAct;        /* Active Region (F1) */
    #if (CY_UDB_V0)
        uint8   vertFp;     /* Front Porch (D0) */
        uint8   vertSync;   /* Sync Width  (D1) */
    #endif /* (CY_UDB_V0) */
    
    /* SRAM access configuration for panel refreshing */
    #if (CY_UDB_V0)
        uint32 frameAddr;   /* Frame buffer address */
        uint32 lineIncr;    /* Increment at the end of a line */
    #endif /* (CY_UDB_V0) */   
} GraphicLCDCtrl_1_BACKUP_STRUCT;


/***************************************
*        Function Prototypes            
***************************************/

void    GraphicLCDCtrl_1_Start(void)                        ;
void    GraphicLCDCtrl_1_Stop(void)                         ;
void    GraphicLCDCtrl_1_Write(uint32 addr, uint16 wrData)  ;
uint16  GraphicLCDCtrl_1_Read(uint32 addr)                  ;
void    GraphicLCDCtrl_1_WriteFrameAddr(uint32 addr)        ;
uint32  GraphicLCDCtrl_1_ReadFrameAddr(void)                ;
void    GraphicLCDCtrl_1_WriteLineIncr(uint32 incr)         ;
uint32  GraphicLCDCtrl_1_ReadLineIncr(void)                 ;

void    GraphicLCDCtrl_1_Sleep(void)                        ;
void    GraphicLCDCtrl_1_Wakeup(void)                       ;
void    GraphicLCDCtrl_1_Enable(void)                       ;
void    GraphicLCDCtrl_1_Init(void)                         ;
void    GraphicLCDCtrl_1_SaveConfig(void)                   ;
void    GraphicLCDCtrl_1_RestoreConfig(void)                ;

/* Defines to allow call these APIs by emWinGraphics */
#define CYGRAPHICS_START()              GraphicLCDCtrl_1_Start()
#define CYGRAPHICS_STOP()               GraphicLCDCtrl_1_Stop()
#define CYGRAPHICS_READ(addr)           GraphicLCDCtrl_1_Read(addr)
#define CYGRAPHICS_WRITE(addr, data)    GraphicLCDCtrl_1_Write(addr, data)
#define CYGRAPHICS_WRITE_FRAME(addr)    GraphicLCDCtrl_1_WriteFrameAddr(addr)
#define CYGRAPHICS_READ_FRAME()         GraphicLCDCtrl_1_ReadFrameAddr()
#define CYGRAPHICS_WRITE_INCR(incr)     GraphicLCDCtrl_1_WriteLineIncr(incr)
#define CYGRAPHICS_READ_INCR()          GraphicLCDCtrl_1_ReadLineIncr()


/***************************************
*           API Constants               
***************************************/

#define GraphicLCDCtrl_1_CMD_FIFO_FULL            (0x01u)
#define GraphicLCDCtrl_1_DATA_VALID               (0x02u)
#define GraphicLCDCtrl_1_HORIZ_BLANKING           (0x04u)
#define GraphicLCDCtrl_1_VERT_BLANKING            (0x08u)

#define GraphicLCDCtrl_1_READ_ADDR_MASK           (0x800000u)
#define GraphicLCDCtrl_1_WRITE_ADDR_MASK          (0x7FFFFFu)

#define GraphicLCDCtrl_1_INIT_FRAME_ADDRESS       (0x000000u)
#define GraphicLCDCtrl_1_INIT_LINE_INCR           (0x000000u)

#define GraphicLCDCtrl_1_DISABLED                 (0u)


/***************************************
*    Enumerated Types and Parameters    
***************************************/


/***************************************
*    Initial Parameter Constants        
***************************************/

/* Sync Width in dotclks. Set one less than period */
#define GraphicLCDCtrl_1_HORIZ_SYNC_WIDTH   (2u - 1u)
/* Back Porch in dotclks. Set 6 less than period because the BP is split into
 * two pieces to keep random access from extending into the active period. */
#define GraphicLCDCtrl_1_HORIZ_BACK_PORCH   (66u - 6u)
/* Active Region in dotclks. Set as (period / 4) - 1. This allows for regions 
 * as large as 1024x1024 while only using 8 bit counters. */
#define GraphicLCDCtrl_1_HORIZ_ACTIVE_REG   ((320u >> 2u) - 1u)
/* Front Porch in dotclks. Set one less than period */
#define GraphicLCDCtrl_1_HORIZ_FRONT_PORCH  (20u - 1u)

/* Sync Width in lines. Set one less than period. */
#define GraphicLCDCtrl_1_VERT_SYNC_WIDTH    (2u - 1u)
/* Back Porch in lines. Set one less than period. */
#define GraphicLCDCtrl_1_VERT_BACK_PORCH    (16u - 1u)
/* Active Region in lines. Set as (period / 4) - 1. This allows for regions 
 * as large as 1024x1024 while only using 8 bit counters. */
#define GraphicLCDCtrl_1_VERT_ACTIVE_REG    ((240u >> 2u) - 1u)
/* Front Porch in lines. Set one less than period. */
#define GraphicLCDCtrl_1_VERT_FRONT_PORCH   (4u - 1u)

/* Phisical line width. 
 * Used to compute the value to add at the end of each line. */
#define GraphicLCDCtrl_1_PHYS_LINE_WIDTH    (320u)


/***************************************
*             Registers                 
***************************************/

/* Control register definition */
#define GraphicLCDCtrl_1_CONTROL_REG   (* (reg8 *) GraphicLCDCtrl_1_SyncCtl_ControlReg__CONTROL_REG)
#define GraphicLCDCtrl_1_CONTROL_PTR   (  (reg8 *) GraphicLCDCtrl_1_SyncCtl_ControlReg__CONTROL_REG)

/* Status register definition */
#define GraphicLCDCtrl_1_STATUS_REG                 (* (reg8 *) GraphicLCDCtrl_1_StatusReg__STATUS_REG)
#define GraphicLCDCtrl_1_STATUS_PTR                 (  (reg8 *) GraphicLCDCtrl_1_StatusReg__STATUS_REG)

/* Internal defines to use with emWin. For some functionality emWin requires
 * the knowledge of what interval is going on. */
#define CYGRAPHICS_IS_VBLANKING     (0u != (GraphicLCDCtrl_1_STATUS_REG & GraphicLCDCtrl_1_VERT_BLANKING))
#define CYGRAPHICS_IS_HBLANKING     (0u != (GraphicLCDCtrl_1_STATUS_REG & GraphicLCDCtrl_1_HORIZ_BLANKING))

/* Horizontal timing configuration registers definition */
#define GraphicLCDCtrl_1_HORIZ_DP_AUX_CTL_REG       (* (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__DP_AUX_CTL_REG)
#define GraphicLCDCtrl_1_HORIZ_DP_AUX_CTL_PTR       (  (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__DP_AUX_CTL_REG)
#define GraphicLCDCtrl_1_HORIZ_SYNC_REG             (* (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__D1_REG)
#define GraphicLCDCtrl_1_HORIZ_SYNC_PTR             (  (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__D1_REG)
#define GraphicLCDCtrl_1_HORIZ_BP_REG               (* (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__F0_REG)
#define GraphicLCDCtrl_1_HORIZ_BP_PTR               (  (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__F0_REG)
#define GraphicLCDCtrl_1_HORIZ_ACT_REG              (* (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__F1_REG)
#define GraphicLCDCtrl_1_HORIZ_ACT_PTR              (  (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__F1_REG)
#define GraphicLCDCtrl_1_HORIZ_FP_REG               (* (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__D0_REG)
#define GraphicLCDCtrl_1_HORIZ_FP_PTR               (  (reg8 *) GraphicLCDCtrl_1_HorizDatapath_u0__D0_REG)

/* Vertical timing configuration registers definition */
#define GraphicLCDCtrl_1_VERT_DP_AUX_CTL_REG        (* (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__DP_AUX_CTL_REG)
#define GraphicLCDCtrl_1_VERT_DP_AUX_CTL_PTR        (  (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__DP_AUX_CTL_REG)
#define GraphicLCDCtrl_1_VERT_SYNC_REG              (* (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__D1_REG)
#define GraphicLCDCtrl_1_VERT_SYNC_PTR              (  (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__D1_REG)
#define GraphicLCDCtrl_1_VERT_BP_REG                (* (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__F0_REG)
#define GraphicLCDCtrl_1_VERT_BP_PTR                (  (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__F0_REG)
#define GraphicLCDCtrl_1_VERT_ACT_REG               (* (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__F1_REG)
#define GraphicLCDCtrl_1_VERT_ACT_PTR               (  (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__F1_REG)
#define GraphicLCDCtrl_1_VERT_FP_REG                (* (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__D0_REG)
#define GraphicLCDCtrl_1_VERT_FP_PTR                (  (reg8 *) GraphicLCDCtrl_1_VertDatapath_u0__D0_REG)

/* Frame buffer address register definition */
#define GraphicLCDCtrl_1_FRAME_BUF_LSB_PTR          (  (reg32 *) GraphicLCDCtrl_1_AddrDp0__D0_REG)

/* Increment at the and of a line register definition */
#define GraphicLCDCtrl_1_LINE_INCR_LSB_PTR          (  (reg32 *) GraphicLCDCtrl_1_AddrDp0__D1_REG)

/* Command/random memory access address register definition */ 
#define GraphicLCDCtrl_1_ADDR_LSB_PTR               (  (reg32 *) GraphicLCDCtrl_1_AddrDp0__F1_REG)

/* 16-bit input data bus. Used for data during read transaction */  
#define GraphicLCDCtrl_1_DIN_LSB_PTR                (  (reg16 *) GraphicLCDCtrl_1_LsbDp__F1_REG)

/* Lower 8 bit of the output data bus. Used for data during write transaction */
#define GraphicLCDCtrl_1_DOUT_LSB_REG               (* (reg8 *) GraphicLCDCtrl_1_LsbDp__F0_REG)
#define GraphicLCDCtrl_1_DOUT_LSB_PTR               (  (reg8 *) GraphicLCDCtrl_1_LsbDp__F0_REG)
/* Lower 8 bit of the output data bus. Used for data during write transaction */
#define GraphicLCDCtrl_1_DOUT_MSB_REG               (* (reg8 *) GraphicLCDCtrl_1_MsbDp__F0_REG)
#define GraphicLCDCtrl_1_DOUT_MSB_PTR               (  (reg8 *) GraphicLCDCtrl_1_MsbDp__F0_REG)


/***************************************
*       Register Constants              
***************************************/

#define GraphicLCDCtrl_1_FX_CLEAR                   (0x03u)
#define GraphicLCDCtrl_1_ENABLE                     (0x01u)
#define GraphicLCDCtrl_1_RESET                      (0x2u)

#endif /* CY_GraphicLCDCtrl_GraphicLCDCtrl_1_H */


/* [] END OF FILE */
