/*******************************************************************************
* File Name: PI_DONE.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PI_DONE.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PI_DONE__PORT == 15 && ((PI_DONE__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PI_DONE_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PI_DONE_Write(uint8 value) 
{
    uint8 staticBits = (PI_DONE_DR & (uint8)(~PI_DONE_MASK));
    PI_DONE_DR = staticBits | ((uint8)(value << PI_DONE_SHIFT) & PI_DONE_MASK);
}


/*******************************************************************************
* Function Name: PI_DONE_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PI_DONE_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PI_DONE_0, mode);
}


/*******************************************************************************
* Function Name: PI_DONE_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PI_DONE_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PI_DONE_Read(void) 
{
    return (PI_DONE_PS & PI_DONE_MASK) >> PI_DONE_SHIFT;
}


/*******************************************************************************
* Function Name: PI_DONE_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PI_DONE_ReadDataReg(void) 
{
    return (PI_DONE_DR & PI_DONE_MASK) >> PI_DONE_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PI_DONE_INTSTAT) 

    /*******************************************************************************
    * Function Name: PI_DONE_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PI_DONE_ClearInterrupt(void) 
    {
        return (PI_DONE_INTSTAT & PI_DONE_MASK) >> PI_DONE_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
