/*******************************************************************************
* File Name: PO_RESETN.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PO_RESETN.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PO_RESETN__PORT == 15 && ((PO_RESETN__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PO_RESETN_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PO_RESETN_Write(uint8 value) 
{
    uint8 staticBits = (PO_RESETN_DR & (uint8)(~PO_RESETN_MASK));
    PO_RESETN_DR = staticBits | ((uint8)(value << PO_RESETN_SHIFT) & PO_RESETN_MASK);
}


/*******************************************************************************
* Function Name: PO_RESETN_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PO_RESETN_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PO_RESETN_0, mode);
}


/*******************************************************************************
* Function Name: PO_RESETN_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PO_RESETN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PO_RESETN_Read(void) 
{
    return (PO_RESETN_PS & PO_RESETN_MASK) >> PO_RESETN_SHIFT;
}


/*******************************************************************************
* Function Name: PO_RESETN_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PO_RESETN_ReadDataReg(void) 
{
    return (PO_RESETN_DR & PO_RESETN_MASK) >> PO_RESETN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PO_RESETN_INTSTAT) 

    /*******************************************************************************
    * Function Name: PO_RESETN_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PO_RESETN_ClearInterrupt(void) 
    {
        return (PO_RESETN_INTSTAT & PO_RESETN_MASK) >> PO_RESETN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
