/*******************************************************************************
* File Name: ROM_SCK.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ROM_SCK.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 ROM_SCK__PORT == 15 && ((ROM_SCK__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: ROM_SCK_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void ROM_SCK_Write(uint8 value) 
{
    uint8 staticBits = (ROM_SCK_DR & (uint8)(~ROM_SCK_MASK));
    ROM_SCK_DR = staticBits | ((uint8)(value << ROM_SCK_SHIFT) & ROM_SCK_MASK);
}


/*******************************************************************************
* Function Name: ROM_SCK_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void ROM_SCK_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ROM_SCK_0, mode);
}


/*******************************************************************************
* Function Name: ROM_SCK_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ROM_SCK_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ROM_SCK_Read(void) 
{
    return (ROM_SCK_PS & ROM_SCK_MASK) >> ROM_SCK_SHIFT;
}


/*******************************************************************************
* Function Name: ROM_SCK_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ROM_SCK_ReadDataReg(void) 
{
    return (ROM_SCK_DR & ROM_SCK_MASK) >> ROM_SCK_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ROM_SCK_INTSTAT) 

    /*******************************************************************************
    * Function Name: ROM_SCK_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ROM_SCK_ClearInterrupt(void) 
    {
        return (ROM_SCK_INTSTAT & ROM_SCK_MASK) >> ROM_SCK_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
