/*******************************************************************************
* File Name: SCS_N.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SCS_N.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SCS_N__PORT == 15 && ((SCS_N__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SCS_N_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SCS_N_Write(uint8 value) 
{
    uint8 staticBits = (SCS_N_DR & (uint8)(~SCS_N_MASK));
    SCS_N_DR = staticBits | ((uint8)(value << SCS_N_SHIFT) & SCS_N_MASK);
}


/*******************************************************************************
* Function Name: SCS_N_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SCS_N_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SCS_N_0, mode);
}


/*******************************************************************************
* Function Name: SCS_N_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SCS_N_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SCS_N_Read(void) 
{
    return (SCS_N_PS & SCS_N_MASK) >> SCS_N_SHIFT;
}


/*******************************************************************************
* Function Name: SCS_N_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SCS_N_ReadDataReg(void) 
{
    return (SCS_N_DR & SCS_N_MASK) >> SCS_N_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SCS_N_INTSTAT) 

    /*******************************************************************************
    * Function Name: SCS_N_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SCS_N_ClearInterrupt(void) 
    {
        return (SCS_N_INTSTAT & SCS_N_MASK) >> SCS_N_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
