/*******************************************************************************
* File Name: SPI3_MO.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SPI3_MO.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SPI3_MO__PORT == 15 && ((SPI3_MO__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SPI3_MO_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SPI3_MO_Write(uint8 value) 
{
    uint8 staticBits = (SPI3_MO_DR & (uint8)(~SPI3_MO_MASK));
    SPI3_MO_DR = staticBits | ((uint8)(value << SPI3_MO_SHIFT) & SPI3_MO_MASK);
}


/*******************************************************************************
* Function Name: SPI3_MO_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SPI3_MO_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SPI3_MO_0, mode);
	CyPins_SetPinDriveMode(SPI3_MO_1, mode);
	CyPins_SetPinDriveMode(SPI3_MO_2, mode);
}


/*******************************************************************************
* Function Name: SPI3_MO_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SPI3_MO_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SPI3_MO_Read(void) 
{
    return (SPI3_MO_PS & SPI3_MO_MASK) >> SPI3_MO_SHIFT;
}


/*******************************************************************************
* Function Name: SPI3_MO_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SPI3_MO_ReadDataReg(void) 
{
    return (SPI3_MO_DR & SPI3_MO_MASK) >> SPI3_MO_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SPI3_MO_INTSTAT) 

    /*******************************************************************************
    * Function Name: SPI3_MO_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SPI3_MO_ClearInterrupt(void) 
    {
        return (SPI3_MO_INTSTAT & SPI3_MO_MASK) >> SPI3_MO_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
