/*******************************************************************************
* File Name: SPI5_MOMI.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SPI5_MOMI.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SPI5_MOMI__PORT == 15 && ((SPI5_MOMI__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SPI5_MOMI_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SPI5_MOMI_Write(uint8 value) 
{
    uint8 staticBits = (SPI5_MOMI_DR & (uint8)(~SPI5_MOMI_MASK));
    SPI5_MOMI_DR = staticBits | ((uint8)(value << SPI5_MOMI_SHIFT) & SPI5_MOMI_MASK);
}


/*******************************************************************************
* Function Name: SPI5_MOMI_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SPI5_MOMI_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SPI5_MOMI_0, mode);
	CyPins_SetPinDriveMode(SPI5_MOMI_1, mode);
	CyPins_SetPinDriveMode(SPI5_MOMI_2, mode);
	CyPins_SetPinDriveMode(SPI5_MOMI_3, mode);
	CyPins_SetPinDriveMode(SPI5_MOMI_4, mode);
}


/*******************************************************************************
* Function Name: SPI5_MOMI_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SPI5_MOMI_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SPI5_MOMI_Read(void) 
{
    return (SPI5_MOMI_PS & SPI5_MOMI_MASK) >> SPI5_MOMI_SHIFT;
}


/*******************************************************************************
* Function Name: SPI5_MOMI_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SPI5_MOMI_ReadDataReg(void) 
{
    return (SPI5_MOMI_DR & SPI5_MOMI_MASK) >> SPI5_MOMI_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SPI5_MOMI_INTSTAT) 

    /*******************************************************************************
    * Function Name: SPI5_MOMI_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SPI5_MOMI_ClearInterrupt(void) 
    {
        return (SPI5_MOMI_INTSTAT & SPI5_MOMI_MASK) >> SPI5_MOMI_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
