/*******************************************************************************
* File Name: TDI.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TDI.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 TDI__PORT == 15 && ((TDI__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: TDI_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void TDI_Write(uint8 value) 
{
    uint8 staticBits = (TDI_DR & (uint8)(~TDI_MASK));
    TDI_DR = staticBits | ((uint8)(value << TDI_SHIFT) & TDI_MASK);
}


/*******************************************************************************
* Function Name: TDI_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void TDI_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(TDI_0, mode);
}


/*******************************************************************************
* Function Name: TDI_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TDI_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TDI_Read(void) 
{
    return (TDI_PS & TDI_MASK) >> TDI_SHIFT;
}


/*******************************************************************************
* Function Name: TDI_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TDI_ReadDataReg(void) 
{
    return (TDI_DR & TDI_MASK) >> TDI_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TDI_INTSTAT) 

    /*******************************************************************************
    * Function Name: TDI_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TDI_ClearInterrupt(void) 
    {
        return (TDI_INTSTAT & TDI_MASK) >> TDI_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
