/*******************************************************************************
* File Name: TMS.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TMS.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 TMS__PORT == 15 && ((TMS__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: TMS_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void TMS_Write(uint8 value) 
{
    uint8 staticBits = (TMS_DR & (uint8)(~TMS_MASK));
    TMS_DR = staticBits | ((uint8)(value << TMS_SHIFT) & TMS_MASK);
}


/*******************************************************************************
* Function Name: TMS_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void TMS_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(TMS_0, mode);
}


/*******************************************************************************
* Function Name: TMS_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TMS_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TMS_Read(void) 
{
    return (TMS_PS & TMS_MASK) >> TMS_SHIFT;
}


/*******************************************************************************
* Function Name: TMS_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TMS_ReadDataReg(void) 
{
    return (TMS_DR & TMS_MASK) >> TMS_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TMS_INTSTAT) 

    /*******************************************************************************
    * Function Name: TMS_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TMS_ClearInterrupt(void) 
    {
        return (TMS_INTSTAT & TMS_MASK) >> TMS_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
